@@ -1,21 +1,20 @@
 package Acme::Mitey::Cards::Card;
 
-our $VERSION   = '0.009';
+our $VERSION   = '0.010';
 our $AUTHORITY = 'cpan:TOBYINK';
 
 use Acme::Mitey::Cards::Mite qw( -bool -is carp );
-
-use Acme::Mitey::Cards::Suit;
+use Acme::Mitey::Cards::Types qw(:types);
 
 has deck => (
 	is       => ro,
-	isa      => 'Deck',
+	isa      => Deck,
 	weak_ref => true,
 );
 
 has reverse => (
 	is       => lazy,
-	isa      => 'Str',
+	isa      => Str,
 	builder  => sub { shift->deck->reverse },
 );
 
