@@ -1,11 +1,13 @@
 {
 
     package Acme::Mitey::Cards::Card;
-    our $USES_MITE = "Mite::Class";
-    our $MITE_SHIM = "Acme::Mitey::Cards::Mite";
     use strict;
     use warnings;
 
+    our $USES_MITE    = "Mite::Class";
+    our $MITE_SHIM    = "Acme::Mitey::Cards::Mite";
+    our $MITE_VERSION = "0.006012";
+
     BEGIN {
         *bare  = \&Acme::Mitey::Cards::Mite::bare;
         *carp  = \&Acme::Mitey::Cards::Mite::carp;
@@ -100,6 +102,7 @@
 
     sub __META__ {
         no strict 'refs';
+        no warnings 'once';
         my $class = shift;
         $class = ref($class) || $class;
         my $linear_isa = mro::get_linear_isa($class);
