@@ -1,23 +1,25 @@
 package Acme::Mitey::Cards::Card::Face;
 
-our $VERSION   = '0.009';
+our $VERSION   = '0.010';
 our $AUTHORITY = 'cpan:TOBYINK';
 
 use Acme::Mitey::Cards::Mite qw( -bool -is );
+use Acme::Mitey::Cards::Types qw(:types);
+
 extends 'Acme::Mitey::Cards::Card';
 
 use Acme::Mitey::Cards::Suit;
 
 has suit => (
 	is       => ro,
-	isa      => 'Suit',
+	isa      => Suit,
 	required => true,
 	coerce   => true,
 );
 
 has face => (
 	is       => ro,
-	isa      => 'Character',
+	isa      => Character,
 	required => true,
 );
 
