@@ -1,14 +1,16 @@
 package Acme::Mitey::Cards::Hand;
 
-our $VERSION   = '0.009';
+our $VERSION   = '0.010';
 our $AUTHORITY = 'cpan:TOBYINK';
 
 use Acme::Mitey::Cards::Mite qw( -bool -is );
+use Acme::Mitey::Cards::Types qw(:types);
+
 extends 'Acme::Mitey::Cards::Set';
 
 has owner => (
 	is       => rw,
-	isa      => 'Str|Object',
+	isa      => StringOrObject,
 );
 
 1;
