@@ -1,11 +1,13 @@
 {
 
     package Acme::Mitey::Cards::Hand;
-    our $USES_MITE = "Mite::Class";
-    our $MITE_SHIM = "Acme::Mitey::Cards::Mite";
     use strict;
     use warnings;
 
+    our $USES_MITE    = "Mite::Class";
+    our $MITE_SHIM    = "Acme::Mitey::Cards::Mite";
+    our $MITE_VERSION = "0.006012";
+
     BEGIN {
         *bare  = \&Acme::Mitey::Cards::Mite::bare;
         *false = \&Acme::Mitey::Cards::Mite::false;
@@ -90,7 +92,7 @@
               }
               or Acme::Mitey::Cards::Mite::croak
               "Type check failed in constructor: %s should be %s", "owner",
-              "Str|Object";
+              "StringOrObject";
             $self->{"owner"} = $args->{"owner"};
         }
 
@@ -106,51 +108,6 @@
         return $self;
     }
 
-    sub BUILDALL {
-        my $class = ref( $_[0] );
-        my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
-        $_->(@_) for @{ $meta->{BUILD} || [] };
-    }
-
-    sub DESTROY {
-        my $self  = shift;
-        my $class = ref($self) || $self;
-        my $meta  = ( $Mite::META{$class} ||= $class->__META__ );
-        my $in_global_destruction =
-          defined ${^GLOBAL_PHASE}
-          ? ${^GLOBAL_PHASE} eq 'DESTRUCT'
-          : Devel::GlobalDestruction::in_global_destruction();
-        for my $demolisher ( @{ $meta->{DEMOLISH} || [] } ) {
-            my $e = do {
-                local ( $?, $@ );
-                eval { $demolisher->( $self, $in_global_destruction ) };
-                $@;
-            };
-            no warnings 'misc';    # avoid (in cleanup) warnings
-            die $e if $e;          # rethrow
-        }
-        return;
-    }
-
-    sub __META__ {
-        no strict 'refs';
-        my $class = shift;
-        $class = ref($class) || $class;
-        my $linear_isa = mro::get_linear_isa($class);
-        return {
-            BUILD => [
-                map { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
-                map { "$_\::BUILD" } reverse @$linear_isa
-            ],
-            DEMOLISH => [
-                map   { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
-                  map { "$_\::DEMOLISH" } @$linear_isa
-            ],
-            HAS_BUILDARGS        => $class->can('BUILDARGS'),
-            HAS_FOREIGNBUILDARGS => $class->can('FOREIGNBUILDARGS'),
-        };
-    }
-
     sub DOES {
         my ( $self, $role ) = @_;
         our %DOES;
@@ -194,7 +151,7 @@
               }
               or Acme::Mitey::Cards::Mite::croak(
                 "Type check failed in %s: value should be %s",
-                "accessor", "Str|Object" );
+                "accessor", "StringOrObject" );
             $_[0]{"owner"} = $_[1];
             $_[0];
           }
