@@ -1,15 +1,16 @@
 package Acme::Mitey::Cards::Set;
 
-our $VERSION   = '0.009';
+our $VERSION   = '0.010';
 our $AUTHORITY = 'cpan:TOBYINK';
 
 use Acme::Mitey::Cards::Mite qw( -bool -is croak );
+use Acme::Mitey::Cards::Types qw(:types);
 
 use List::Util ();
 
 has cards => (
 	is       => lazy,
-	isa      => 'CardArray',
+	isa      => CardArray,
 );
 
 sub _build_cards {
